# python-sdk

[![semantic-release](https://img.shields.io/badge/%20%20%F0%9F%93%A6%F0%9F%9A%80-semantic--release-e10079.svg)](https://github.com/semantic-release/semantic-release)
[![Build Status](https://travis-ci.org/hexonet/python-sdk.svg?branch=master)](https://travis-ci.org/hexonet/python-sdk)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/hexonet.apiconnector.svg)](https://www.python.org/)
[![PyPI](https://img.shields.io/pypi/v/hexonet.apiconnector.svg)](https://pypi.org/project/hexonet.apiconnector/)
[![Documentation Status](https://readthedocs.org/projects/hexonet-python-sdk/badge/?version=latest)](https://hexonet-python-sdk.readthedocs.io/en/latest/?badge=latest)
[![License: MIT](https://img.shields.io/badge/License-MIT-blue.svg)](https://opensource.org/licenses/MIT)
[![PRs welcome](https://img.shields.io/badge/PRs-welcome-brightgreen.svg)](https://github.com/hexonet/python-sdk/blob/master/CONTRIBUTING.md)

This module is a connector library for the insanely fast HEXONET Backend API. For further informations visit our [homepage](http://hexonet.net) and do not hesitate to [contact us](https://www.hexonet.net/contact).

## Resources

* [Usage Guide](https://hexonet-python-sdk.readthedocs.io/en/latest/#usage-guide)
* [SDK Documentation](https://hexonet-python-sdk.readthedocs.io/en/latest/#sdk-documentation)
* [HEXONET Backend API Documentation](https://github.com/hexonet/hexonet-api-documentation/tree/master/API)
* [Release Notes](https://github.com/hexonet/python-sdk/releases)
* [Development Guide](https://hexonet-python-sdk.readthedocs.io/en/latest/developmentguide.html)

## How to use this module in your project

All you need to know, can be found [here](https://hexonet-python-sdk.readthedocs.io/en/latest/#usage-guide).

## Contributing

Please read [our development guide](https://hexonet-python-sdk.readthedocs.io/en/latest/developmentguide.html) for details on our code of conduct, and the process for submitting pull requests to us.

```bash
pip3 install -e .
```

## Authors

List of responsible developers can be found [here](https://github.com/hexonet/python-sdk/blob/master/AUTHORS.md)

See also the list of [contributors](https://github.com/hexonet/php-sdk/graphs/contributors) who participated in this project.

## License

This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details.
